@@ -40,16 +40,13 @@ struct _editor_data_t
   GtkListStore* systemsoundLevel;
 
   GtkWidget* vibratingCheckbutton;
-  GtkWidget* silentCheckbutton;
-  /* unused
-  GtkWidget* clockalarmCheckbutton;
-  GtkWidget* calendaralarmCheckbutton;
-  */
+
   GtkListStore* ringingTone;
   GtkListStore* smsTone;
   GtkListStore* imTone;
   GtkListStore* emailTone;  
   GstElement* sound_player;
+  profilesx_profile_data* profile_data;
 };
 
 void play_sound(const gchar* file, editor_data_t* data)
@@ -60,6 +57,7 @@ void play_sound(const gchar* file, editor_data_t* data)
   int stret = gst_element_get_state(data->sound_player, &state, &pending, GST_CLOCK_TIME_NONE);
   g_object_set(data->sound_player, "uri", g_filename_to_uri(file, NULL, NULL));
   int ret2 = gst_element_set_state(data->sound_player, GST_STATE_PLAYING);
+ 
 }
 
 gchar* get_profile_display_name(const gchar* profile_name)
@@ -145,7 +143,7 @@ void read_predefined_ringtones(editor_data_t* data)
 }
 
 gchar*
-get_display_value_from_file_name(gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
+get_display_value_from_file_name(const gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
 {
   GFile* file;
   gchar* basename;
@@ -158,7 +156,7 @@ get_display_value_from_file_name(gchar* value, GtkListStore* list_store, GtkTree
 }
 
 gchar*
-get_display_value(gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
+get_display_value(const gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
 {
   gboolean valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(list_store), iter);
   while (valid)
@@ -182,32 +180,17 @@ get_display_value(gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
 }
 
 void 
-set_profile_tone_value(const gchar* profile_name, const gchar* key, GtkWidget* button, GtkListStore* list_store)
+set_profile_tone_value(const gchar* tone, GtkWidget* button, GtkListStore* list_store)
 {
-  gchar* value = profile_get_value(profile_name, key);
   GtkTreeIter iter;
-  gchar* display_value = get_display_value(value, list_store, &iter);
-  //  hildon_touch_selector_select_iter(HILDON_TOUCH_SELECTOR(selector), 0, &iter, TRUE);
+  gchar* display_value = get_display_value(tone, list_store, &iter);
   hildon_button_set_value(HILDON_BUTTON(button), display_value);
-  g_free(value);
   g_free(display_value);
 }
 
 void
-set_profile_volume_value(const gchar* profile_name, const gchar* key, GtkWidget* slider)
+set_profile_sound_level_value(const int value, GtkWidget* button)
 {
-  int slider_value;
-  slider_value = profile_get_value_as_int(profile_name,
-					  key);
-  gtk_range_set_value(GTK_RANGE(slider), slider_value);
-
-}
-
-void
-set_profile_sound_level_value(const gchar* profile_name, const gchar* key, GtkWidget* button)
-{
-  int value = profile_get_value_as_int(profile_name, key);
-
   GtkTreeIter iter;
   hildon_picker_button_set_active(HILDON_PICKER_BUTTON(button), value);
   HildonTouchSelector* selector = 
@@ -236,36 +219,9 @@ set_profile_sound_level_value(const gchar* profile_name, const gchar* key, GtkWi
   }
 }
 
-void
-set_profile_checkbutton_value(const gchar* profile_name, const gchar* key, GtkWidget* checkbutton)
+void set_profile_status_icon_value(editor_data_t* data)
 {
-  gboolean active = profile_get_value_as_bool(profile_name, key);
-  if(active)
-    hildon_check_button_set_active(HILDON_CHECK_BUTTON(checkbutton), TRUE);
-  else
-    hildon_check_button_set_active(HILDON_CHECK_BUTTON(checkbutton), FALSE);
-}
-
-void
-set_profile_silent_checkbutton_value(const gchar* profile_name, const gchar* key, GtkWidget* checkbutton)
-{
-  gchar* type = profile_get_value(profile_name, key);
-  if(g_strcmp0(type, "ringing")==0)
-    hildon_check_button_set_active(HILDON_CHECK_BUTTON(checkbutton), FALSE);
-  else
-    hildon_check_button_set_active(HILDON_CHECK_BUTTON(checkbutton), TRUE);
-}
-
-void set_profile_status_icon_value(const gchar* profile_name, GtkWidget* button)
-{
-  GKeyFile *keyFile;
-  FILE *iniFile;
-  gchar *filename;
-  gchar* icon_name = NULL;
-  keyFile = g_key_file_new();
-  filename = g_strconcat (g_get_home_dir(), PROFILESX_PLUGIN_SETTINGS_FILE, NULL);
-  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
-  icon_name = g_key_file_get_string(keyFile, profile_name, "icon", NULL);
+  gchar* icon_name = data->profile_data->status_bar_icon_name;
   if(icon_name!=NULL)
   {
     GtkWidget* image;
@@ -275,35 +231,33 @@ void set_profile_status_icon_value(const gchar* profile_name, GtkWidget* button)
     else
       image = gtk_image_new_from_file(icon_name);
     
-    g_object_set(G_OBJECT(image), "name", icon_name);
-    gtk_button_set_image(GTK_BUTTON(button), image);
+    gtk_button_set_image(GTK_BUTTON(data->iconButton), image);
   }
-  g_key_file_free (keyFile); 
-  g_free (filename); 
-  g_free(icon_name);
 }
 
 void
 set_profile_values(const gchar* profile_name, editor_data_t* data)
 {
-  set_profile_tone_value(profile_name, PROFILEKEY_RINGING_ALERT_TONE, data->ringtoneButton, data->ringingTone);
-  set_profile_tone_value(profile_name, PROFILEKEY_SMS_ALERT_TONE, data->smstoneButton, data->smsTone);
-  set_profile_tone_value(profile_name, PROFILEKEY_EMAIL_ALERT_TONE, data->emailtoneButton, data->emailTone);
-  set_profile_tone_value(profile_name, PROFILEKEY_IM_ALERT_TONE, data->imtoneButton, data->imTone);
-  set_profile_volume_value(profile_name, PROFILEKEY_RINGING_ALERT_VOLUME, data->ringtoneVolumeSlider);
-  set_profile_volume_value(profile_name, PROFILEKEY_EMAIL_ALERT_VOLUME, data->emailVolumeSlider);
-  set_profile_volume_value(profile_name, PROFILEKEY_IM_ALERT_VOLUME, data->imVolumeSlider);
-  set_profile_volume_value(profile_name, PROFILEKEY_SMS_ALERT_VOLUME, data->smsVolumeSlider);
-  set_profile_sound_level_value(profile_name, PROFILEKEY_KEYPAD_SOUND_LEVEL, data->keypadsoundLevelButton);
-  set_profile_sound_level_value(profile_name, PROFILEKEY_TOUCHSCREEN_SOUND_LEVEL, data->touchscreensoundLevelButton);
-  set_profile_sound_level_value(profile_name, PROFILEKEY_SYSTEM_SOUND_LEVEL, data->systemsoundLevelButton);
-  set_profile_checkbutton_value(profile_name, PROFILEKEY_VIBRATING_ALERT_ENABLED, data->vibratingCheckbutton);
-  //  set_profile_silent_checkbutton_value(profile_name, PROFILEKEY_RINGING_ALERT_TYPE, data->silentCheckbutton);
-  /* unused
-  set_profile_checkbutton_value(profile_name, PROFILEKEY_CLOCK_ALARM_ENABLED, data->clockalarmCheckbutton);
-  set_profile_checkbutton_value(profile_name, PROFILEKEY_CALENDAR_ALARM_ENABLED, data->calendaralarmCheckbutton);
-  */
-  set_profile_status_icon_value(profile_name, data->iconButton);
+  set_profile_tone_value(data->profile_data->ringing_tone, data->ringtoneButton, data->ringingTone);
+  set_profile_tone_value(data->profile_data->sms_tone, data->smstoneButton, data->smsTone);
+  set_profile_tone_value(data->profile_data->im_tone, data->imtoneButton, data->imTone);
+  set_profile_tone_value(data->profile_data->email_tone, data->emailtoneButton, data->emailTone);
+  set_profile_sound_level_value(data->profile_data->keypad_sound_level, data->keypadsoundLevelButton);
+  set_profile_sound_level_value(data->profile_data->touchscreen_sound_level, data->touchscreensoundLevelButton);
+  set_profile_sound_level_value(data->profile_data->system_sound_level, data->systemsoundLevelButton);
+
+  gtk_range_set_value(GTK_RANGE(data->ringtoneVolumeSlider), data->profile_data->ringing_volume);
+  gtk_range_set_value(GTK_RANGE(data->smsVolumeSlider), data->profile_data->sms_volume);
+  gtk_range_set_value(GTK_RANGE(data->imVolumeSlider), data->profile_data->im_volume);
+  gtk_range_set_value(GTK_RANGE(data->emailVolumeSlider), data->profile_data->email_volume);
+
+  if(data->profile_data->vibrating_enabled)
+    hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton), TRUE);
+  else
+    hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton), FALSE);
+
+  
+  set_profile_status_icon_value(data);
 }
 
 void
@@ -330,116 +284,45 @@ get_iter_for_value(GtkListStore* list_store, const gchar* value, GtkTreeIter* it
   }
 }
 
-void
-save_profile_checkbutton_value(const gchar* profile_name, const gchar* key, GtkWidget* checkbutton)
-{
-  gboolean active = hildon_check_button_get_active(HILDON_CHECK_BUTTON(checkbutton));
-  profile_set_value_as_bool(profile_name, key, active);
-}
-
-void
-save_profile_silent_checkbutton_value(const gchar* profile_name, const gchar* key, GtkWidget* checkbutton)
-{
-  gboolean active = hildon_check_button_get_active(HILDON_CHECK_BUTTON(checkbutton));
-  if(active)
-  {
-    profile_set_value(profile_name, key, "silent");
-  }
-  else
-  {
-    profile_set_value(profile_name, key, "ringing");
-  }
-}
-
 void 
-save_profile_tone_value(const gchar* profile_name, const gchar* key, GtkWidget* button, GtkListStore* list_store)
+save_profile_tone_value(gchar** tone, GtkWidget* button, GtkListStore* list_store)
 {
   GtkTreeIter iter;
   const gchar* value = hildon_button_get_value(HILDON_BUTTON(button));
   get_iter_for_value(list_store, value, &iter);
-  gchar* list_value;
-  gchar* key_value;
   gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter,
-		     0, &key_value,
-		     1, &list_value,
+		     1, tone,
 		     -1);
-  profile_set_value(profile_name, key, list_value);
-  g_free(list_value);
-}
-void
-save_profile_volume_value(const gchar* profile_name, const gchar* key, GtkWidget* slider)
-{
-  int slider_value;
-  slider_value = (int)gtk_range_get_value(GTK_RANGE(slider));
-  profile_set_value_as_int(profile_name,
-			   key, slider_value);
-}
-void
-save_profile_sound_level_value(const gchar* profile_name, const gchar* key, GtkWidget* button)
-{
-  int value = hildon_touch_selector_get_active(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON(button)),
-					       0);
-  profile_set_value_as_int(profile_name, key, value);
-}
-
-void save_profile_status_icon_value(const gchar* profile_name, GtkWidget* button)
-{
-  gchar* icon_name = NULL;
-  GtkImage* image = GTK_IMAGE(GTK_BUTTON(gtk_button_get_image(GTK_BUTTON(button))));
-  if(image!=NULL)
-  {
-    g_object_get(G_OBJECT(image), "icon-name", &icon_name);
-    if(icon_name==NULL)
-    {
-      g_object_get(G_OBJECT(GTK_BUTTON(gtk_button_get_image(GTK_BUTTON(button)))), "name", &icon_name);
-    }
-  }
-
-  GKeyFile *keyFile;
-  gchar *fileData;
-  FILE *iniFile;
-  gsize size;
-  gchar *filename;
-
-  keyFile = g_key_file_new();
-  filename = g_strconcat (g_get_home_dir(), PROFILESX_PLUGIN_SETTINGS_FILE, NULL);
-  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
-  if(icon_name!=NULL)
-    g_key_file_set_string(keyFile, profile_name, "icon", icon_name);
-  else
-    g_key_file_remove_key(keyFile, profile_name, "icon", NULL);
-
-  fileData = g_key_file_to_data (keyFile, &size, NULL);
-  g_file_set_contents(filename, fileData, size, NULL);
-
-  g_key_file_free (keyFile); 
-  g_free (fileData); 
-  g_free (filename); 
-  g_free(icon_name);
-
 }
 
 void
 save_profile_values(const gchar* profile_name, editor_data_t* data)
 {
-  save_profile_tone_value(profile_name, PROFILEKEY_RINGING_ALERT_TONE, data->ringtoneButton, data->ringingTone);
-  save_profile_tone_value(profile_name, PROFILEKEY_SMS_ALERT_TONE, data->smstoneButton, data->smsTone);
-  save_profile_tone_value(profile_name, PROFILEKEY_EMAIL_ALERT_TONE, data->emailtoneButton, data->emailTone);
-  save_profile_tone_value(profile_name, PROFILEKEY_IM_ALERT_TONE, data->imtoneButton, data->imTone);
-  save_profile_volume_value(profile_name, PROFILEKEY_RINGING_ALERT_VOLUME, data->ringtoneVolumeSlider);
-  save_profile_volume_value(profile_name, PROFILEKEY_EMAIL_ALERT_VOLUME, data->emailVolumeSlider);
-  save_profile_volume_value(profile_name, PROFILEKEY_IM_ALERT_VOLUME, data->imVolumeSlider);
-  save_profile_volume_value(profile_name, PROFILEKEY_SMS_ALERT_VOLUME, data->smsVolumeSlider);
-  save_profile_sound_level_value(profile_name, PROFILEKEY_KEYPAD_SOUND_LEVEL, data->keypadsoundLevelButton);
-  save_profile_sound_level_value(profile_name, PROFILEKEY_TOUCHSCREEN_SOUND_LEVEL, data->touchscreensoundLevelButton);
-  save_profile_sound_level_value(profile_name, PROFILEKEY_SYSTEM_SOUND_LEVEL, data->systemsoundLevelButton);
-  save_profile_checkbutton_value(profile_name, PROFILEKEY_VIBRATING_ALERT_ENABLED, data->vibratingCheckbutton);
-  //  save_profile_silent_checkbutton_value(profile_name, PROFILEKEY_RINGING_ALERT_TYPE, data->silentCheckbutton);
-  /* unused
-  save_profile_checkbutton_value(profile_name, PROFILEKEY_CLOCK_ALARM_ENABLED, data->clockalarmCheckbutton);
-  save_profile_checkbutton_value(profile_name, PROFILEKEY_CALENDAR_ALARM_ENABLED, data->calendaralarmCheckbutton);
-  */
-  save_profile_status_icon_value(profile_name, data->iconButton);
+  g_free(data->profile_data->ringing_tone);
+  g_free(data->profile_data->sms_tone);
+  g_free(data->profile_data->im_tone);
+  g_free(data->profile_data->email_tone);
+  save_profile_tone_value(&(data->profile_data->ringing_tone), data->ringtoneButton, data->ringingTone);
+  save_profile_tone_value(&(data->profile_data->sms_tone), data->smstoneButton, data->smsTone);
+  save_profile_tone_value(&(data->profile_data->im_tone), data->imtoneButton, data->imTone);
+  save_profile_tone_value(&(data->profile_data->email_tone), data->emailtoneButton, data->emailTone);
+
+  data->profile_data->ringing_volume = (int)gtk_range_get_value(GTK_RANGE(data->ringtoneVolumeSlider));
+  data->profile_data->sms_volume = (int)gtk_range_get_value(GTK_RANGE(data->smsVolumeSlider));
+  data->profile_data->im_volume = (int)gtk_range_get_value(GTK_RANGE(data->imVolumeSlider));
+  data->profile_data->email_volume = (int)gtk_range_get_value(GTK_RANGE(data->emailVolumeSlider));
+  data->profile_data->keypad_sound_level = 
+    hildon_touch_selector_get_active(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON(data->keypadsoundLevelButton)),
+				     0);
+  data->profile_data->touchscreen_sound_level = 
+    hildon_touch_selector_get_active(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON(data->touchscreensoundLevelButton)),
+									    0);
+  data->profile_data->system_sound_level = 
+    hildon_touch_selector_get_active(hildon_picker_button_get_selector(HILDON_PICKER_BUTTON(data->systemsoundLevelButton)),
+									    0);
+
+  data->profile_data->vibrating_enabled = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton));
+  profilesx_store_profile_data(profile_name, data->profile_data);
 }
 
 void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
@@ -452,10 +335,14 @@ void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
   dialog = hildon_file_chooser_dialog_new(GTK_WINDOW(parent),
 					  GTK_FILE_CHOOSER_ACTION_OPEN);
   GtkFileFilter* fileFilter = gtk_file_filter_new();
-  gtk_file_filter_add_mime_type(fileFilter, "audio/mpeg3");
-  gtk_file_filter_add_mime_type(fileFilter, "audio/mp3");
+  gtk_file_filter_add_mime_type(fileFilter, "audio/mpeg");
+  gtk_file_filter_add_mime_type(fileFilter, "audio/x-wav");
+  //  gtk_file_filter_add_mime_type(fileFilter, "audio/midi");
+  gtk_file_filter_add_mime_type(fileFilter, "audio/mp4");
   gtk_file_filter_add_mime_type(fileFilter, "audio/aac");
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), fileFilter);
+
+
   gtk_widget_show_all(GTK_WIDGET(dialog));
   
   int ret = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -492,11 +379,14 @@ show_tone_selector(GtkListStore* list_store, GtkWidget* button, GtkWidget* selec
 {
   GtkTreeIter iter;
   GtkWidget* more_button;
+
   get_iter_for_value(list_store, hildon_button_get_value(HILDON_BUTTON(button)), &iter);
   
   hildon_touch_selector_select_iter(HILDON_TOUCH_SELECTOR(selector),
 				    0,
 				    &iter, TRUE);
+
+
   int sound_handler_id = g_signal_connect(selector, "changed", G_CALLBACK(play_sound_sample), data);
   GtkWidget* dialog = gtk_dialog_new_with_buttons(dgettext("osso-profiles", "profi_fi_ringingtone_tone"),
 						  NULL,
@@ -631,50 +521,28 @@ void init_editor_tone_selector_widgets(editor_data_t* app_data)
   
 }
 
-void init_tone_volume_slider(GtkWidget** slider)
-{
-  GtkWidget* widget = hildon_gtk_hscale_new();
-  gtk_scale_set_digits(GTK_SCALE(widget), 0);
-  gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(widget)),
-			   0,
-			   0,
-			   100,
-			   1,
-			   0,
-			   0);
-			   
-  (*slider) = widget;
-}
-
 void init_editor_tone_volume_widgets(editor_data_t* app_data)
 {
-  init_tone_volume_slider(&app_data->ringtoneVolumeSlider);
-  init_tone_volume_slider(&app_data->smsVolumeSlider);
-  init_tone_volume_slider(&app_data->emailVolumeSlider);
-  init_tone_volume_slider(&app_data->imVolumeSlider);
-}
-
-void init_checkbutton_widget(GtkWidget** checkbutton, gchar* title)
-{
-  GtkWidget* widget = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
-  gtk_button_set_label(GTK_BUTTON(widget),
-		       title);
-  hildon_check_button_set_active(HILDON_CHECK_BUTTON(widget), TRUE);
-  (*checkbutton) = widget;
-}
-
-void init_editor_checkbutton_widgets(editor_data_t* app_data)
-{
-  init_checkbutton_widget(&app_data->vibratingCheckbutton,
-			  dgettext("osso-profiles", "profi_fi_general_vibrate"));
-/*   init_checkbutton_widget(&app_data->silentCheckbutton, */
-/* 			  dgettext("osso-profiles", "profi_bd_silent")); */
-  /* unused
-  init_checkbutton_widget(&app_data->clockalarmCheckbutton,
-			  dgettext("osso-clock","cloc_ti_alarms"));
-  init_checkbutton_widget(&app_data->calendaralarmCheckbutton,
-			  dgettext("calendar", "cal_ap_name"));
-  */
+  app_data->ringtoneVolumeSlider = hildon_gtk_hscale_new();
+  gtk_scale_set_digits(GTK_SCALE(app_data->ringtoneVolumeSlider), 0);
+  gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(app_data->ringtoneVolumeSlider)),
+			   0, 0, 100, 1, 0, 0);
+			   
+  app_data->smsVolumeSlider = hildon_gtk_hscale_new();
+  gtk_scale_set_digits(GTK_SCALE(app_data->smsVolumeSlider), 0);
+  gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(app_data->smsVolumeSlider)),
+			   0, 0, 100, 1, 0, 0);
+			   
+  app_data->imVolumeSlider = hildon_gtk_hscale_new();
+  gtk_scale_set_digits(GTK_SCALE(app_data->imVolumeSlider), 0);
+  gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(app_data->imVolumeSlider)),
+			   0, 0, 100, 1, 0, 0);
+			   
+  app_data->emailVolumeSlider = hildon_gtk_hscale_new();
+  gtk_scale_set_digits(GTK_SCALE(app_data->emailVolumeSlider), 0);
+  gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(app_data->emailVolumeSlider)),
+			   0, 0, 100, 1, 0, 0);
+			   
 }
 
 GtkWidget* create_sound_level_widget(GtkListStore* list_store, gchar* title)
@@ -702,40 +570,7 @@ GtkWidget* create_sound_level_widget(GtkListStore* list_store, gchar* title)
   return widget;
 }
 
-void init_sound_level_list_store(GtkListStore* list_store)
-{
-  GtkTreeIter iter;
-  gtk_list_store_append(list_store, &iter);
-  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_off"), 1, 0, -1);
-  gtk_list_store_append(list_store, &iter);
-  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level1"), 1, 1, -1);
-  gtk_list_store_append(list_store, &iter);
-  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level2"), 1, 2, -1);
-}
-
-void init_editor_sound_level_widgets(editor_data_t* app_data)
-{
-  app_data->keypadsoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-  app_data->touchscreensoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-  app_data->systemsoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-
-  init_sound_level_list_store(app_data->keypadsoundLevel);
-  init_sound_level_list_store(app_data->systemsoundLevel);
-  init_sound_level_list_store(app_data->touchscreensoundLevel);
-
-  app_data->keypadsoundLevelButton = 
-    create_sound_level_widget(app_data->keypadsoundLevel,
-			      dgettext("osso-profiles", "profi_fi_key_sounds"));
-  app_data->touchscreensoundLevelButton = 
-    create_sound_level_widget(app_data->touchscreensoundLevel,
-			      dgettext("osso-profiles", "profi_fi_touch_screen_sounds"));
-
-  app_data->systemsoundLevelButton = 
-    create_sound_level_widget(app_data->systemsoundLevel,
-			      dgettext("osso-profiles", "profi_fi_system_sounds"));
-}
-
-void load_custom_icon(GtkButton* button, editor_data_t* app_data)
+void load_custom_icon(GtkButton* button, gchar** icon_path)
 {
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
   {
@@ -744,7 +579,6 @@ void load_custom_icon(GtkButton* button, editor_data_t* app_data)
     dialog = hildon_file_chooser_dialog_new(GTK_WINDOW(parent),
 					    GTK_FILE_CHOOSER_ACTION_OPEN);
     GtkFileFilter* fileFilter = gtk_file_filter_new();
-    //    gtk_file_filter_add_pattern(fileFilter, "*.png");
     gtk_file_filter_add_pixbuf_formats(fileFilter);
     gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), fileFilter);
 
@@ -753,10 +587,9 @@ void load_custom_icon(GtkButton* button, editor_data_t* app_data)
     if(ret == GTK_RESPONSE_OK)
     {
       gchar* filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
+      (*icon_path) = filename;
       GtkWidget* image = gtk_image_new_from_file(filename);
-      g_object_set(G_OBJECT(image), "name", filename);
       gtk_button_set_image(button, image);
-      //      g_free(filename);
     }
     gtk_widget_destroy(dialog);
   }
@@ -764,6 +597,12 @@ void load_custom_icon(GtkButton* button, editor_data_t* app_data)
 
 void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
 {
+  const gchar* icon_name_silent = "statusarea_silent";
+  const gchar* icon_name_home = "statusarea_profilesx_home";
+  const gchar* icon_name_im = "statusarea_profilesx_im";
+  const gchar* icon_name_outside = "statusarea_profilesx_outside";
+  const gchar* icon_name_loud = "statusarea_profilesx_loud";
+
   GtkWidget* dialog = gtk_dialog_new_with_buttons("Statusbar icon",
 						  NULL,
 						  GTK_DIALOG_MODAL,
@@ -771,6 +610,7 @@ void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
 						  GTK_RESPONSE_OK,
 						  NULL);
   GtkWidget* icon_box = gtk_hbox_new(TRUE, 0);
+
   GtkWidget* icon_button_none = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT,
 									NULL);
   GtkWidget* icon_button_silent = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT,
@@ -793,80 +633,93 @@ void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_loud), FALSE);
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_custom), FALSE);
 
-  //  gtk_button_set_image(GTK_BUTTON(icon_button_none), gtk_image_new_from_icon_name("statusarea_silent", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_silent), gtk_image_new_from_icon_name("statusarea_silent", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_home), gtk_image_new_from_icon_name("statusarea_profilesx_home", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_im), gtk_image_new_from_icon_name("statusarea_profilesx_im", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_outside), gtk_image_new_from_icon_name("statusarea_profilesx_outside", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_loud), gtk_image_new_from_icon_name("statusarea_profilesx_loud", 18));
-  gtk_button_set_image(GTK_BUTTON(icon_button_custom), gtk_image_new_from_icon_name("statusarea_profilesx_custom", 18));
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_none);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_silent);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_home);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_im);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_outside);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_loud);
-  gtk_container_add(GTK_CONTAINER(icon_box), icon_button_custom);
-  g_signal_connect(icon_button_custom, "clicked", G_CALLBACK(load_custom_icon), app_data);
+  gtk_button_set_image(GTK_BUTTON(icon_button_silent), gtk_image_new_from_icon_name(icon_name_silent, 18));
+  gtk_button_set_image(GTK_BUTTON(icon_button_home), gtk_image_new_from_icon_name(icon_name_home, 18));
+  gtk_button_set_image(GTK_BUTTON(icon_button_im), gtk_image_new_from_icon_name(icon_name_im, 18));
+  gtk_button_set_image(GTK_BUTTON(icon_button_outside), gtk_image_new_from_icon_name(icon_name_outside, 18));
+  gtk_button_set_image(GTK_BUTTON(icon_button_loud), gtk_image_new_from_icon_name(icon_name_loud, 18));
+  gtk_button_set_image(GTK_BUTTON(icon_button_custom), gtk_image_new_from_icon_name("general_folder", 18));
+
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_none, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_silent, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_home, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_im, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_outside, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(icon_box), icon_button_loud, TRUE, TRUE, 0);
+  gtk_box_pack_end(GTK_BOX(icon_box), icon_button_custom, TRUE, TRUE, 3);
+  gchar* custom_icon_name = NULL;
+  g_signal_connect(icon_button_custom, "clicked", G_CALLBACK(load_custom_icon), &custom_icon_name);
+
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), icon_box);
   
   gtk_widget_show_all(dialog);
   int ret = gtk_dialog_run(GTK_DIALOG(dialog));
   if(ret == GTK_RESPONSE_OK)
   {
-    GSList* list = gtk_radio_button_get_group(GTK_RADIO_BUTTON(icon_button_custom));
-    gboolean found = FALSE;
-    while(list && !found)
+    g_free(app_data->profile_data->status_bar_icon_name);
+    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_custom)))
     {
-      found = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data));
-      if(found)
-      {
-	gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(list->data)));
-      }
-      list = list->next;
+      app_data->profile_data->status_bar_icon_name = custom_icon_name;
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_custom)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_none)))
+    {
+      app_data->profile_data->status_bar_icon_name = NULL;
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_none)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_silent)))
+    {
+      app_data->profile_data->status_bar_icon_name = g_strdup(icon_name_silent);
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_silent)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_home)))
+    {
+      app_data->profile_data->status_bar_icon_name = g_strdup(icon_name_home);
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_home)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_im)))
+    {
+      app_data->profile_data->status_bar_icon_name = g_strdup(icon_name_im);
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_im)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_outside)))
+    {
+      app_data->profile_data->status_bar_icon_name = g_strdup(icon_name_outside);
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_outside)));
+    }
+    else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(icon_button_loud)))
+    {
+      app_data->profile_data->status_bar_icon_name = g_strdup(icon_name_loud);
+      gtk_button_set_image(button, gtk_button_get_image(GTK_BUTTON(icon_button_loud)));
     }
-    
   }
   gtk_widget_destroy(dialog);
 }
 
-void init_editor_status_icon_widget(editor_data_t* app_data)
+
+void init_sound_level_list_store(GtkListStore* list_store)
 {
-  app_data->iconButton = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
-					   HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-  g_signal_connect(app_data->iconButton, "clicked", G_CALLBACK(icon_selection_dialog), app_data);
+  GtkTreeIter iter;
+  gtk_list_store_append(list_store, &iter);
+  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_off"), 1, 0, -1);
+  gtk_list_store_append(list_store, &iter);
+  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level1"), 1, 1, -1);
+  gtk_list_store_append(list_store, &iter);
+  gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level2"), 1, 2, -1);
 }
 
-void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement* sound_player)
+void layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget* dialog)
 {
-  GtkWidget* dialog;
   GtkWidget* content_area;
   GtkWidget* pannable_area;
-  editor_data_t* data = g_new0(editor_data_t, 1);
-
-
-  init_editor_status_icon_widget(data);
-  init_editor_tone_selector_widgets(data);
-  init_editor_tone_volume_widgets(data);
-  init_editor_sound_level_widgets(data);
-  init_editor_checkbutton_widgets(data);
-  set_profile_values(profile_name, data);
-  data->sound_player = sound_player;
-  dialog = gtk_dialog_new_with_buttons(get_profile_display_name(profile_name),
-				       GTK_WINDOW(main_dialog),
-				       GTK_DIALOG_MODAL,
-				       dgettext("hildon-libs", "wdgt_bd_save"), GTK_RESPONSE_OK,
-				       NULL);
-  
-  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 300);
-  content_area = gtk_vbox_new(FALSE, 3);
   GtkWidget* iconBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* ringtoneBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* smsBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* imBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* emailBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* icon_label = gtk_label_new("Statusbar icon");
-  
+
+
   gtk_box_pack_start(GTK_BOX(iconBox), icon_label, TRUE, TRUE, 0); 
   gtk_box_pack_end(GTK_BOX(iconBox), data->iconButton, TRUE, TRUE, 0); 
   gtk_box_pack_start(GTK_BOX(ringtoneBox), data->ringtoneButton, TRUE, TRUE, 0);
@@ -881,25 +734,87 @@ void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstEl
   gtk_box_pack_start(GTK_BOX(emailBox), data->emailtoneButton, TRUE, TRUE, 0);
   gtk_box_pack_end(GTK_BOX(emailBox), data->emailVolumeSlider, TRUE, TRUE, 0);
 
-  gtk_container_add(GTK_CONTAINER(content_area), iconBox);
-  gtk_container_add(GTK_CONTAINER(content_area), data->vibratingCheckbutton);
-  gtk_container_add(GTK_CONTAINER(content_area), data->silentCheckbutton);
-  gtk_container_add(GTK_CONTAINER(content_area), ringtoneBox);
-  gtk_container_add(GTK_CONTAINER(content_area), smsBox);
-  gtk_container_add(GTK_CONTAINER(content_area), imBox);
-  gtk_container_add(GTK_CONTAINER(content_area), emailBox);
-  gtk_container_add(GTK_CONTAINER(content_area), data->keypadsoundLevelButton);
-  gtk_container_add(GTK_CONTAINER(content_area), data->touchscreensoundLevelButton);
-  gtk_container_add(GTK_CONTAINER(content_area), data->systemsoundLevelButton);
+  if(g_strcmp0(profile_name, "silent")!=0)
+  {
+    content_area = gtk_vbox_new(FALSE, 3);  
+    gtk_container_add(GTK_CONTAINER(content_area), iconBox);
+    gtk_container_add(GTK_CONTAINER(content_area), data->vibratingCheckbutton);
+    gtk_container_add(GTK_CONTAINER(content_area), ringtoneBox);
+    gtk_container_add(GTK_CONTAINER(content_area), smsBox);
+    gtk_container_add(GTK_CONTAINER(content_area), imBox);
+    gtk_container_add(GTK_CONTAINER(content_area), emailBox);
+    gtk_container_add(GTK_CONTAINER(content_area), data->keypadsoundLevelButton);
+    gtk_container_add(GTK_CONTAINER(content_area), data->touchscreensoundLevelButton);
+    gtk_container_add(GTK_CONTAINER(content_area), data->systemsoundLevelButton);
+    pannable_area = hildon_pannable_area_new();
+    hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area);
+    gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
+		      pannable_area);
+  }
+  else
+  {
+    content_area = gtk_vbox_new(FALSE, 3);  
+    gtk_box_pack_start(GTK_BOX(content_area), iconBox, TRUE, TRUE, 3);
+    gtk_box_pack_end(GTK_BOX(content_area), data->vibratingCheckbutton, TRUE, TRUE, 3);
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
+		       content_area,
+		       FALSE, FALSE, 0);
+  }
+}
 
-  /* unused
-  gtk_container_add(GTK_CONTAINER(content_area), data->clockalarmCheckbutton);
-  gtk_container_add(GTK_CONTAINER(content_area), data->calendaralarmCheckbutton);
-  */
-  pannable_area = hildon_pannable_area_new();
-  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area);
-  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
-		    pannable_area);
+void init_editor_dialog_widgets(editor_data_t* data)
+{
+  data->iconButton = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
+					   HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+  g_signal_connect(data->iconButton, "clicked", G_CALLBACK(icon_selection_dialog), data);
+
+  init_editor_tone_selector_widgets(data);
+  init_editor_tone_volume_widgets(data);
+  
+  data->keypadsoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+  data->touchscreensoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+  data->systemsoundLevel = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+
+  init_sound_level_list_store(data->keypadsoundLevel);
+  init_sound_level_list_store(data->systemsoundLevel);
+  init_sound_level_list_store(data->touchscreensoundLevel);
+
+  data->keypadsoundLevelButton = 
+    create_sound_level_widget(data->keypadsoundLevel,
+			      dgettext("osso-profiles", "profi_fi_key_sounds"));
+  data->touchscreensoundLevelButton = 
+    create_sound_level_widget(data->touchscreensoundLevel,
+			      dgettext("osso-profiles", "profi_fi_touch_screen_sounds"));
+
+  data->systemsoundLevelButton = 
+    create_sound_level_widget(data->systemsoundLevel,
+			      dgettext("osso-profiles", "profi_fi_system_sounds"));
+
+  data->vibratingCheckbutton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(data->vibratingCheckbutton),
+		       dgettext("osso-profiles", "profi_fi_general_vibrate"));
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton), TRUE);
+}
+
+void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement* sound_player)
+{
+  GtkWidget* dialog;
+  editor_data_t* data = g_new0(editor_data_t, 1);
+  data->profile_data = g_new0(profilesx_profile_data, 1);
+  profilesx_load_profile_data(profile_name,
+			      data->profile_data);
+
+  dialog = gtk_dialog_new_with_buttons(get_profile_display_name(profile_name),
+				       GTK_WINDOW(main_dialog),
+				       GTK_DIALOG_MODAL,
+				       dgettext("hildon-libs", "wdgt_bd_save"), GTK_RESPONSE_OK,
+				       NULL);
+  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 300);  
+  init_editor_dialog_widgets(data);
+  set_profile_values(profile_name, data);
+  data->sound_player = sound_player;
+
+  layout_dialog_widgets(profile_name, data, dialog);
   gtk_widget_show_all(dialog);
 
   int ret = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -922,5 +837,6 @@ void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstEl
   g_object_unref(data->keypadsoundLevel);
   g_object_unref(data->touchscreensoundLevel);
   g_object_unref(data->systemsoundLevel);
+  profilesx_free_profile_data(data->profile_data);
   g_free(data);
 }
